=======
Credits
=======

Development Lead
----------------

* Tasos Katsoulas <akatsoulas@mozilla.com>
* John Giannelos <jgiannelos@mozilla.com>

Contributors
------------

* Will Kahn-Greene
* Peter Bengtsson <@peterbe>
